@@ -2,6 +2,7 @@ import json
 
 from six import string_types
 
+from jet_bridge_base import settings
 from jet_bridge_base.exceptions.missing_argument_error import MissingArgumentError
 
 _ARG_DEFAULT = object()
@@ -9,6 +10,9 @@ _ARG_DEFAULT = object()
 
 class Request(object):
 
+    session = None
+    bridge_settings = None
+
     def __init__(
             self,
             method=None,
@@ -23,7 +27,8 @@ class Request(object):
             body_arguments=None,
             files=None,
             original_request=None,
-            original_handler=None
+            original_handler=None,
+            action=None
     ):
         self.method = method
         self.protocol = protocol
@@ -38,6 +43,7 @@ class Request(object):
         self.files = files or {}
         self.original_request = original_request
         self.original_handler = original_handler
+        self.action = action
 
         content_type = self.headers.get('CONTENT_TYPE', '')
 
@@ -88,3 +94,23 @@ class Request(object):
                 v = v.strip()
             values.append(v)
         return values
+
+    def get_bridge_settings(self):
+        if self.bridge_settings:
+            return self.bridge_settings
+
+        bridge_settings_encoded = self.headers.get('X_BRIDGE_SETTINGS')
+
+        if not bridge_settings_encoded:
+            return
+
+        from jet_bridge_base.utils.crypt import decrypt
+
+        try:
+            secret_key = settings.TOKEN.replace('-', '').lower()
+            decrypted = decrypt(bridge_settings_encoded, secret_key)
+            self.bridge_settings = json.loads(decrypted)
+            return self.bridge_settings
+        except Exception:
+            return
+
