@@ -39,6 +39,7 @@ class SqlSerializer(Serializer):
             try:
                 session.execute('SET TIME ZONE :tz', {'tz': data['timezone']})
             except SQLAlchemyError:
+                session.rollback()
                 pass
 
         try:
@@ -54,8 +55,23 @@ class SqlSerializer(Serializer):
                     return
                 return x
 
-            return {'data': rows, 'columns': list(map(map_column, result.keys()))}
-        except (SQLAlchemyError, TypeError) as e:
+            def map_row_column(x):
+                if isinstance(x, bytes):
+                    try:
+                        return x.decode('utf-8')
+                    except UnicodeDecodeError:
+                        return x.hex()
+                else:
+                    return x
+
+            def map_row(x):
+                return list(map(map_row_column, x))
+
+            return {'data': list(map(map_row, rows)), 'columns': list(map(map_column, result.keys()))}
+        except SQLAlchemyError as e:
+            session.rollback()
+            raise SqlError(e)
+        except TypeError as e:
             raise SqlError(e)
         finally:
             session.close()
